Detect whether the current R session is running in RStudio to decide whether themes can be applied to the IDE.
See also
Package helpers:
generate_uuid()
Detect whether the current R session is running in RStudio to decide whether themes can be applied to the IDE.
Package helpers:
generate_uuid()