Detect whether the current R session is running in RStudio, which is used to decide whether themes can be applied to the IDE.
See also
Helper functions:
generate_uuid()
Detect whether the current R session is running in RStudio, which is used to decide whether themes can be applied to the IDE.
Helper functions:
generate_uuid()