Detect whether the current R session is running in RStudio, used to decide if themes can be applied to the IDE.
See also
Other helpers:
generate_uuid()
Detect whether the current R session is running in RStudio, used to decide if themes can be applied to the IDE.
Other helpers:
generate_uuid()